/*
Some utility commands:
- `nix flake update --commit-lock-file`
- `nix flake lock update-input <input>`
- `nix build .#ji-chan` or `nix build .`
- `nix run .#ji-chan` or `nix run .`
*/

{
  description = "Discord bot for the Tegaki Tuesday handwriting challenge";

  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-unstable";
    rust-overlay.url = "github:oxalica/rust-overlay";
  };

  outputs = { self, nixpkgs, rust-overlay }:
    let
      overlays = [ (import rust-overlay) ];
      system = "x86_64-linux";
      pkgs = import nixpkgs {
        inherit system overlays;
      };
    in {
      devShells.${system}.default = with pkgs; mkShell {
        packages = [
          (pkgs.rust-bin.stable.latest.default.override {
            extensions = [ "rust-src" ];
          })
          cargo-edit
          bacon
        ];
        inputsFrom = with self.packages.${system}; [ ji-chan ];
      };
      packages.${system} = {
        default = self.packages.${system}.ji-chan;
        ji-chan = pkgs.rustPlatform.buildRustPackage {
          src = ./.;
          pname = "ji-chan";
          version = "0.1.0";
          nativeBuildInputs = with pkgs; [ pkg-config ];
          buildInputs = with pkgs; [ openssl ];
          # rustPlatform.fetchCargoTarball is deprecated in favor of rustPlatform.fetchCargoVendor.
          useFetchCargoVendor = true;
          cargoHash = "sha256-eKsQsOIiZDpDOGLMcpU+dL/e/UBEnbQIgcVPKi5xpC8=";
          meta = with nixpkgs.lib; {
            homepage = "https://tegakituesday.com";
            description = "Discord bot for the Tegaki Tuesday handwriting challenge";
            license = [ licenses.gpl3 ];
            platforms = [ system ];
            maintainers = with maintainers; [ elnudev ];
          };
        };
      };
    };
}
